# Watson-Jira

Upload watson time logs to Jira.

**Install:**

`$ pip install watson-jira`


**Upload logs from the last 3 days:**

`$ watson-jira sync --from 3`


**Help:**

`$ watson-jira --help`


Will install TD-Watson https://github.com/TailorDev/Watson as one of it's dependencies, not surprisingly.
